==> haskell-simple-sendfile-0.2.31-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-sendfile
version:              0.2.31
visibility:           public
id:                   simple-sendfile-0.2.31-IZqXLp3MnRa5b9k5iug7GJ
key:                  simple-sendfile-0.2.31-IZqXLp3MnRa5b9k5iug7GJ
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  a6289f47de9aa1d82a389eb071fb1d93
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.0.2/site-local/simple-sendfile-0.2.31
library-dirs:         /usr/lib/ghc-9.0.2/site-local/simple-sendfile-0.2.31
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.31-IZqXLp3MnRa5b9k5iug7GJ
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    network-3.1.4.0-5PP4MrJJnZZJkybIlRRAPq unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.32-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-EjyJfcS19cljcR3HW5un0
key:                  simple-sendfile-0.2.32-EjyJfcS19cljcR3HW5un0
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  64de0bd64feea86f52a3f5a083144112
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.2.8/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.2.8/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-EjyJfcS19cljcR3HW5un0
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    network-3.1.4.0-HWJHph1qrvp6tEtZHv7We0 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
